package com.chelvc.cloud.maintain.controller;

import javax.validation.Valid;

import com.chelvc.cloud.maintain.copier.MerchantCopier;
import com.chelvc.cloud.maintain.param.CustomerIndexParam;
import com.chelvc.cloud.maintain.vo.CustomerIndexVO;
import com.chelvc.cloud.uc.api.service.UsageService;
import com.chelvc.cloud.vehicle.api.param.NearbyQueryParam;
import com.chelvc.cloud.vehicle.api.service.MerchantService;
import com.chelvc.framework.base.annotation.UnifiedResponseBody;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 首页接口
 *
 * @author Woody
 * @date 2023/5/4
 */
@Validated
@RestController
@UnifiedResponseBody
public class IndexController {
    @DubboReference
    private UsageService usageService;

    @DubboReference
    private MerchantService merchantService;

    /**
     * 刷新用户使用记录
     */
    @PostMapping("/usage")
    public void refreshUsage() {
        this.usageService.refresh();
    }

    /**
     * 顾客端首页信息
     *
     * @param param 首页参数
     * @return 首页信息
     */
    @GetMapping("/customer/index")
    public CustomerIndexVO getCustomerIndex(@Valid CustomerIndexParam param) {
        NearbyQueryParam query = NearbyQueryParam.builder().longitude(param.getLongitude())
                .latitude(param.getLatitude()).distance(10000).build();
        CustomerIndexVO index = CustomerIndexVO.builder().build();
        index.setRecommendMerchants(
                MerchantCopier.INSTANCE.copying(this.merchantService.listRecommendMerchants(query, 4))
        );
        index.setNearbyMerchants(
                MerchantCopier.INSTANCE.copying(this.merchantService.listNearbyMerchants(query, 4))
        );
        return index;
    }
}
